@@ -295,19 +295,19 @@
 #'         orderedChar = TRUE, 
 #'         type = "MPR")
 #' 
-#'  #let's compare MPR versus ACCTRAN results
-#'  layout(1:2)
-#'  quickAncPlotter(tree,
-#'         ancMPR, cex = 0.3)
-#'  text(x = 8, y = 15,
-#'         "type = 'MPR'", cex = 1.5)
-#'  quickAncPlotter(tree,
-#'         ancACCTRAN, cex = 0.3)
-#'  text(x = 9, y = 15,
-#'         "type = 'ACCTRAN'",cex = 1.5)
-#' 
-#'  # MPR has much more uncertainty in node estimates
-#' 	 # but that doesn't mean ACCTRAN is preferable
+#' #let's compare MPR versus ACCTRAN results
+#' layout(1:2)
+#' quickAncPlotter(tree,
+#'        ancMPR, cex = 0.3)
+#' text(x = 8, y = 15,
+#'        "type = 'MPR'", cex = 1.5)
+#' quickAncPlotter(tree,
+#'        ancACCTRAN, cex = 0.3)
+#' text(x = 9, y = 15,
+#'        "type = 'ACCTRAN'",cex = 1.5)
+#'        
+#' # MPR has much more uncertainty in node estimates
+#' 	  # but that doesn't mean ACCTRAN is preferable
 #' 
 #' #let's compare unordered versus ordered under MPR
 #' layout(1:2)
@@ -329,13 +329,13 @@
 #' char1 <- matrix(char,,1)
 #' rownames(char1) <- names(char)
 #' #translate into something for phangorn to read
-#' char1 <- phyDat(char1,
+#' char1 <- phangorn::phyDat(char1,
 #'         type = "USER",
 #'         levels = sort(unique(char1))
 #'         )
-#' x <- ancestral.pars(tree,
+#' x <- phangorn::ancestral.pars(tree,
 #'         char1,type = "MPR")
-#' y <- ancestral.pars(tree,
+#' y <- phangorn::ancestral.pars(tree,
 #'         char1,type = "ACCTRAN")
 #' }
 #' 
@@ -708,7 +708,7 @@ ancPropStateMat <- function(trait, tree,
 	char1 <- matrix(trait,,1)
 	rownames(char1) <- names(trait)
 	#translate into something for phangorn to read
-	char1 <- phyDat(char1,
+	char1 <- phangorn::phyDat(char1,
 		type = "USER",
 		levels = trueStates,
 		ambiguity = ambiguity,
@@ -730,7 +730,7 @@ ancPropStateMat <- function(trait, tree,
 		colnames(cost) <- rownames(cost) <- trueStates
 		}
 	#get anc states
-	anc1 <- ancestral.pars(tree,char1,type = type,cost = cost)
+	anc1 <- phangorn::ancestral.pars(tree,char1,type = type,cost = cost)
 	#check to make sure trait data isn't empty
 	if(length(anc1[[1]])<1){
 		stop(paste0("Ancestral reconstruction returned by ancestral.pars",
