@@ -25,7 +25,7 @@ tree2 <- taxa2phylo(taxa2)
 plotTraitgram(trait2,tree2,conf.int = FALSE)
 
 testthat::skip_on_cran()
-testthat::skip_on_travis()
+testthat::skip_on_ci()
 
 expect_equal_to_reference(trait, update=TRUE, 
 	file = ".//references//cladogeneticTrait//trait")
